# Fire Opal Client

The Fire Opal Client package is a Python client for Q-CTRL's Fire Opal product. Fire Opal is a simple and powerful package for algorithm developers and quantum computer end users. By applying a complete suite of error suppression techniques, Fire Opal automatically reduces error and vastly improves the quality of quantum algorithm results. This often transforms quantum computer outputs from random to useful.

See how you can [get started with Fire Opal](https://docs.q-ctrl.com/fire-opal/get-started) today.
